@@ -626,10 +626,16 @@ def quantile_turnover(quantile_factor, quantile, period=1):
     name_shifted = quant_name_sets.shift(periods=period)
 
     new_names = (quant_name_sets - name_shifted).dropna()
-    quant_turnover = (
-        new_names.apply(lambda x: len(x))
-        / quant_name_sets.apply(lambda x: len(x))
-    ).rename(quantile)
+
+    def f(xs):
+        return 0 if pd.isna(xs) else len(xs)
+
+    def g(xs):
+        return 1 if pd.isna(xs) else len(xs)
+
+    quant_turnover = (new_names.apply(f) / quant_name_sets.apply(g)).rename(
+        quantile
+    )
     return quant_turnover
 
 
